@@ -1,4 +1,3 @@
-import re
 from typing import List, Tuple, Optional, Union, Set, Dict
 
 import google
@@ -9,51 +8,11 @@ from bigquery_frame.auth import get_bq_client
 from bigquery_frame.column import Column
 from bigquery_frame.has_bigquery_client import HasBigQueryClient
 from bigquery_frame.printing import print_results
-
+from bigquery_frame.utils import indent, quote, cols_to_str, strip_margin
 
 Column = Union[str, Column]
 
 
-def indent(str, nb) -> str:
-    return " " * nb + str.replace("\n", "\n" + " " * nb)
-
-
-def strip_margin(text):
-    s = re.sub('\n[ \t]*\|', '\n', text)
-    if s.startswith("\n"):
-        return s[1:]
-    else:
-        return s
-
-
-def quote(str) -> str:
-    """Add quotes around a column or table names to prevent collision with SQL keywords.
-    This method is idempotent: it does not add new quotes to an already quoted string.
-    If the column name is a reference to a nested column (i.e. if it contains dots), each part is quoted separately.
-
-    Examples:
-
-    >>> quote("table")
-    '`table`'
-    >>> quote("`table`")
-    '`table`'
-    >>> quote("column.name")
-    '`column`.`name`'
-    >>> quote("*")
-    '*'
-
-    """
-    return '.'.join(['`' + s + '`' if s != '*' else '*' for s in str.replace('`', '').split('.')])
-
-
-def cols_to_str(cols, indentation: Optional[int] = None) -> str:
-    cols = [str(col) for col in cols]
-    if indentation is not None:
-        return indent(",\n".join(cols), indentation)
-    else:
-        return ", ".join(cols)
-
-
 def is_repeated(schema_field: SchemaField):
     return schema_field.mode == "REPEATED"
 
@@ -501,7 +460,7 @@ class DataFrame:
 
     where = filter
 
-    def withColumn(self, col_name: str, col_expr: str, replace: bool = False) -> 'DataFrame':
+    def withColumn(self, col_name: str, col_expr: Column, replace: bool = False) -> 'DataFrame':
         """Returns a new :class:`DataFrame` by adding a column or replacing the existing column that has the same name.
 
         The column expression must be an expression over this :class:`DataFrame`; attempting to add a column from
@@ -630,7 +589,7 @@ class DataFrame:
         , `_default_alias_2` AS (
           SELECT
             a,
-            `a` + 1
+            (`a`) + (1)
           FROM `_default_alias_1`
         )
         SELECT *, a + b AS c FROM `_default_alias_2`
